# User Guide

In this section we provide material how to use radarx.

Most of the material is distributed as jupyter notebooks to be able to interactively explore radarx functionality.

To use radarx in a project:

```python
import radarx
```

```{toctree}
:maxdepth: 2
:caption: Get started
```

```{toctree}
:maxdepth: 2
:caption: Examples

notebooks/IMD_Radar_Data
```
